#
# spec file for package libkolab-qt5
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define php_extdir %{_libdir}/php5/extensions
%define php_confdir %{_sysconfdir}/php5/conf.d
%define libname libkolab1
Name:           libkolab-qt5
Version:        1.0.2
Release:        11.3
Summary:        Conversions from/to KDE containers
License:        LGPL-2.0+ and LGPL-3.0+ and AGPL-3.0+
Group:          Development/Libraries/C and C++
Url:            https://kolab.org/about/libkolab
Source:         libkolab-%{version}.tar.gz
BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.8.9
BuildRequires:  libkolabxml-devel >= 1.1.1
BuildRequires:  libxerces-c-devel
BuildRequires:  php-devel >= 5.3
BuildRequires:  python-devel
BuildRequires:  swig >= 2.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  akonadi-notes-devel
BuildRequires:  akonadi-server-devel
BuildRequires:  kcalcore-devel
BuildRequires:  kcalutils-devel
BuildRequires:  kcontacts-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  kmime-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
libkolab provides conversions from/to KDE containers, mime message handling and facilities
to read and write kolabv2 and kolabv3.
The Akonadi-Kolab-Resource as well as the upgradetool are based on this code.

%package -n %{libname}
Summary:        Conversions from/to KDE containers
Group:          Development/Libraries/C and C++

%description -n %{libname}
libkolab provides conversions from/to KDE containers, mime message handling and facilities
to read and write kolabv2 and kolabv3.
The Akonadi-Kolab-Resource as well as the upgradetool are based on this code.

%package -n php-%{libname}
Summary:        PHP Bindings for libkolab
Group:          Development/Languages/Other
Requires:       %{libname} = %{version}
Provides:       php-kolab = %{version}
Obsoletes:      php-kolab < %{version}
Conflicts:      otherproviders(php-kolab)

%description -n php-%{libname}
libkolab provides conversions from/to KDE containers, mime message handling and facilities
to read and write kolabv2 and kolabv3.
This package provides PHP Bindings for libkolab.

%package -n python-%{libname}
Summary:        Python bindings for libkolab
Group:          Development/Languages/Python
Requires:       %{libname} = %{version}
Provides:       python-kolab = %{version}
Obsoletes:      python-kolab < %{version}
Conflicts:      otherproviders(python-kolab)

%description -n python-%{libname}
libkolab provides conversions from/to KDE containers, mime message handling and facilities
to read and write kolabv2 and kolabv3.
This package provides Python bindings for libkolab.

%package devel
Summary:        Conversions from/to KDE containers
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       akonadi-notes-devel
Requires:       akonadi-server-devel
Requires:       kcalcore-devel
Requires:       kcalutils-devel
Requires:       kcontacts-devel
Requires:       kmime-devel
Requires:       libXerces-c-devel
Requires:       libkolabxml-devel >= 0.8.4
Conflicts:      libkolab-devel

%description devel
libkolab provides conversions from/to KDE containers, mime message handling and facilities
to read and write kolabv2 and kolabv3.
The Akonadi-Kolab-Resource as well as the upgradetool are based on this code.

%prep
%setup -q -n libkolab-%{version}

# TESTS: require X and most fail anyway
%cmake \
    -DLibkolabxml_DIR=%{_libdir}/cmake/Libkolabxml \
%if %{with kde}
    -DUSE_LIBCALENDARING=FALSE \
%else
    -DUSE_LIBCALENDARING=TRUE \
%endif
    -DPHP_BINDINGS=TRUE -DPHP_INSTALL_DIR=%{php_extdir} \
    -DPYTHON_BINDINGS=TRUE -DPYTHON_INSTALL_DIR=%{python_sitearch} \
    -DBUILD_TESTS=FALSE

make %{?_smp_mflags}

%install
# cmake: with earlier releases, we have to change dir manually, as %%cmake_install is not available
%cmake_install

mkdir -p %{buildroot}%{_datadir}/php5
mv %{buildroot}%{php_extdir}/*.php %{buildroot}%{_datadir}/php5/.

mkdir -p %{buildroot}%{php_confdir}
cat >%{buildroot}%{php_confdir}/kolab.ini <<EOF
; Kolab libraries
extension=kolabcalendaring.so
extension=kolabicalendar.so
extension=kolabobject.so
extension=kolabshared.so
EOF

cat >%{buildroot}%{php_confdir}/kolabdummy.ini <<EOF
; Kolab libraries
extension=dummy.so
EOF

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING* README RELEASE-NOTES
%{_libdir}/libkolab.so.*

%files -n php-%{libname}
%defattr(-,root,root)
%config(noreplace) %{php_confdir}/kolab.ini
%config(noreplace) %{php_confdir}/kolabdummy.ini
%{_datadir}/php5/kolabcalendaring.php
%{php_extdir}/kolabcalendaring.so
%{_datadir}/php5/kolabicalendar.php
%{php_extdir}/kolabicalendar.so
%{_datadir}/php5/kolabobject.php
%{php_extdir}/kolabobject.so
%{_datadir}/php5/kolabshared.php
%{php_extdir}/kolabshared.so
%{_datadir}/php5/dummy.php
%{php_extdir}/dummy.so

%files -n python-%{libname}
%defattr(-,root,root)
%dir %{python_sitearch}/kolab
%{python_sitearch}/kolab/_calendaring.so
%{python_sitearch}/kolab/calendaring.py*
%{python_sitearch}/kolab/_icalendar.so
%{python_sitearch}/kolab/icalendar.py*
%{python_sitearch}/kolab/_kolabobject.so
%{python_sitearch}/kolab/kolabobject.py*
%{python_sitearch}/kolab/_shared.so
%{python_sitearch}/kolab/shared.py*

%files devel
%defattr(-,root,root)
%{_includedir}/kolab/
%{_libdir}/libkolab.so
%{_libdir}/cmake/Libkolab/

%changelog
* Thu Jul 21 2016 wbauer@tmo.at
- Adjust build requirements
- Adjust requires of the devel package
* Mon Apr 18 2016 lbeltrame@kde.org
-  Remove akonadi-devel BuildRequire (replaced by
  akonadi-sever-devel)
* Mon Sep 28 2015 tittiatcoke@gmail.com
- Update to version 1.0.2
  * Fix build with latest kdepim libraries
- Drop upstream patch fix_new_kcontact.diff
* Mon Sep 28 2015 tittiatcoke@gmail.com
- Updated patch fix_new_kcontacts.diff to fix building against
  KMime 15.08.1
* Thu Sep 10 2015 mlin@suse.com
- Obsoletes old python-kolab and php-kolab and conflicts the others
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Initial package based on version 1.0.1
  - Supports only Qt5 and KF5
